#
# spec file for package golang-github-wrouesnel-postgres_exporter
#
# Copyright (c) 2017 Silvio Moioli <moio@suse.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%{go_nostrip}

#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%define project github.com/wrouesnel/postgres_exporter
Name:           golang-github-wrouesnel-postgres_exporter
Version:        0.4.7
Release:        1.3.15
License:        Apache-2.0
Summary:        Prometheus exporter for PostgreSQL
Url:            https://prometheus.io/
Group:          System/Management
Source:         postgres_exporter-%{version}.tar.xz
Source1:        prometheus-postgres_exporter.service
Source2:        prometheus-postgres_exporter.sysconfig
Patch0:         architectures.patch
BuildRequires:  golang-packaging
BuildRequires:  golang(API) = 1.9
BuildRequires:  xz
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}
Requires(pre):  shadow
%{go_provides}

%description
Prometheus exporter for PostgreSQL server metrics. Supported PostgreSQL versions: 9.1 and up.

%prep
%setup -q -n postgres_exporter-%{version}
%patch0 -p1

%build
export GOPATH=$HOME/go
mkdir -pv $HOME/go/src/%{project}
cp -avr * $HOME/go/src/%{project}
cd $HOME/go/src/%{project}

go run mage.go binary

%install
cd $HOME/go/src/%{project}
install -D -m 0755 bin/postgres_exporter_v0.0.0_linux-*/postgres_exporter %{buildroot}/%{_bindir}/prometheus-postgres_exporter

install -m755 -d %buildroot%{_fillupdir}
install -m644 %{S:2} %buildroot%{_fillupdir}/sysconfig.prometheus-postgres_exporter

install -D -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/prometheus-postgres_exporter.service
install -Dd -m 0755 %{buildroot}%{_sbindir}
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rcprometheus-postgres_exporter

%pre
%service_add_pre prometheus-postgres_exporter.service
getent group prometheus >/dev/null || %{_sbindir}/groupadd -r prometheus
getent passwd prometheus >/dev/null || %{_sbindir}/useradd -r -g prometheus -d %{_localstatedir}/lib/prometheus -M -s /sbin/nologin prometheus

%post
%fillup_only -n prometheus-postgres_exporter
%service_add_post prometheus-postgres_exporter.service

%preun
%service_del_preun prometheus-postgres_exporter.service

%postun
%service_del_postun prometheus-postgres_exporter.service

%files
%defattr(-,root,root,-)
%doc README.md LICENSE
%{_bindir}/prometheus-postgres_exporter
%{_fillupdir}/sysconfig.prometheus-postgres_exporter
%{_sbindir}/rcprometheus-postgres_exporter
%{_unitdir}/prometheus-postgres_exporter.service

%changelog
* Sat Apr 13 2019 jcavalheiro@suse.com
- Fix ppc64le compile errors on SLE15-SP1
  - Use go1.9 as newer versions break magefile on this arch
- Refactor and cleanup spec file
- Rename systemd service to prometheus-postgres_exporter
* Thu Mar 28 2019 jrenner@suse.com
- Enable building postgres_exporter for additional architectures
  (s390x, ppc64 and arm64)
- Add:
  * architectures.patch
* Wed Mar 27 2019 mc@suse.com
- Upgrade to 0.4.7:
  - Added a query for v9.1 pg_stat_activity.
  - Add `--constantLabels` flag to allow applying fixed constant
    labels to metrics.
  - Support 'B' suffix in units.
* Wed Oct 31 2018 moio@suse.com
- Upgrade to 0.4.6:
  - Fix 32 and 64mb unit sizes, were not supported in pg_settings
  - Add commandline flag to disable default metrics
  - Bugfix for pg_up (it would always be 0)
  - pg_up is now refreshed based on database Ping() every scrape
  - Adds the following environment variables for overriding defaults:
  - `PG_EXPORTER_WEB_LISTEN_ADDRESS`
  - `PG_EXPORTER_WEB_TELEMETRY_PATH`
  - `PG_EXPORTER_EXTEND_QUERY_PATH`
  - Add Content-Type to HTTP landing page
  - Fix panic due to inconsistent label cardinality when using queries.yaml with queries which return extra columns
  - Add metric for whether the user queries YAML file parsed correctly. This also includes the filename and SHA256 sum allowing tracking of updates
  - Add pg_up metric to indicate whether the exporter was able to connect and Ping() the PG instance before a scrape
  - Fix broken link in landing page for `/metrics`
  - Add support for PostgreSQL 10
  - Add support for the 16kB unit when decoding pg_settings
  - Fix DSN logging
  - Ignore functions that cannot be executed during replication recovery
  - Add a `-version` flag finally
  - Add confirmed_flush_lsn to pg_stat_replication
  - use pg_settings to retrieve runtime variables. Adds >180 new metrics and descriptions
* Thu Jun 14 2018 mc@suse.com
- start service after postgresql
* Wed Jun 13 2018 mc@suse.com
- add systemd service and config file
* Wed Mar 29 2017 moio@suse.com
- Initial version
